Learn R Programming

bmabasket (version 0.1.2)

bmabasket-package: bmabasket: Bayesian Model Averaging for Basket Trials

Description

An implementation of the Bayesian model averaging method of Psioda and others (2019) <doi:10.1093/biostatistics/kxz014> for basket trials. Contains a user-friendly wrapper for simulating basket trials under conditions and analyzing them with a Bayesian model averaging approach.

Arguments

See Also

Useful links: